@@ -29,8 +29,7 @@ class Constrain(JupyterMixin):
             yield from console.render(self.renderable, child_options)
 
     def __rich_measure__(self, console: "Console", max_width: int) -> "Measurement":
-        if self.width is None:
-            return Measurement.get(console, self.renderable, max_width)
-        else:
-            width = min(self.width, max_width)
-            return Measurement(width, width)
+        if self.width is not None:
+            max_width = min(self.width, max_width)
+        measurement = Measurement.get(console, self.renderable, max_width)
+        return measurement
