@@ -107,7 +107,7 @@ class Text(JupyterMixin):
         justify (str, optional): Justify method: "left", "center", "full", "right". Defaults to None.
         overflow (str, optional): Overflow method: "crop", "fold", "ellipsis". Defaults to None.
         no_wrap (bool, optional): Disable text wrapping, or None for default. Defaults to None.
-        end (str, optional): Character to end text with. Defaults to "\\n".
+        end (str, optional): Character to end text with. Defaults to "\\\\n".
         tab_size (int): Number of spaces per tab, or ``None`` to use ``console.tab_size``. Defaults to 8.
         spans (List[Span], optional). A list of predefined style spans. Defaults to None.
     """
@@ -279,7 +279,7 @@ class Text(JupyterMixin):
             style (Union[str, Style], optional): Base style for text. Defaults to "".
             justify (str, optional): Justify method: "left", "center", "full", "right". Defaults to None.
             overflow (str, optional): Overflow method: "crop", "fold", "ellipsis". Defaults to None.
-            end (str, optional): Character to end text with. Defaults to "\\n".
+            end (str, optional): Character to end text with. Defaults to "\\\\n".
             tab_size (int): Number of spaces per tab, or ``None`` to use ``console.tab_size``. Defaults to 8.
 
         Returns:
@@ -385,7 +385,7 @@ class Text(JupyterMixin):
             suffix (str): Suffix to remove.
         """
         if self.plain.endswith(suffix):
-            self.plain = self.plain[: -len(suffix)]
+            self.right_crop(len(suffix))
 
     def get_style_at_offset(self, console: "Console", offset: int) -> Style:
         """Get the style of a character at give offset.
@@ -490,7 +490,7 @@ class Text(JupyterMixin):
             whitespace_match = _re_whitespace.search(self.plain)
             if whitespace_match is not None:
                 whitespace_count = len(whitespace_match.group(0))
-                self.plain = self.plain[: -min(whitespace_count, excess)]
+                self.right_crop(min(whitespace_count, excess))
 
     def set_length(self, new_length: int) -> None:
         """Set new length of the text, clipping or padding is required."""
@@ -499,7 +499,7 @@ class Text(JupyterMixin):
             if length < new_length:
                 self.pad_right(new_length - length)
             else:
-                self.plain = self.plain[:new_length]
+                self.right_crop(length - new_length)
 
     def __rich_console__(
         self, console: "Console", options: "ConsoleOptions"
@@ -655,6 +655,7 @@ class Text(JupyterMixin):
                 else:
                     append(part)
         self._text = [result.plain]
+        self._length = len(self.plain)
         self._spans[:] = result._spans
 
     def truncate(
@@ -681,26 +682,23 @@ class Text(JupyterMixin):
                     self.plain = set_cell_size(self.plain, max_width)
             if pad and length < max_width:
                 spaces = max_width - length
-                self.plain = f"{self.plain}{' ' * spaces}"
+                self._text = [f"{self.plain}{' ' * spaces}"]
+                self._length = len(self.plain)
 
     def _trim_spans(self) -> None:
         """Remove or modify any spans that are over the end of the text."""
-        new_length = self._length
-        spans: List[Span] = []
-        append = spans.append
+        # new_length = self._length
+        max_offset = len(self.plain)
         _Span = Span
-        for span in self._spans:
-            if span.end < new_length:
-                append(span)
-                continue
-            if span.start >= new_length:
-                continue
-            if span.end > new_length:
-                start, end, style = span
-                append(_Span(start, min(new_length, end), style))
-            else:
-                append(span)
-        self._spans[:] = spans
+        self._spans[:] = [
+            (
+                span
+                if span.end < max_offset
+                else _Span(span.start, min(max_offset, span.end), span.style)
+            )
+            for span in self._spans
+            if span.start < max_offset
+        ]
 
     def pad(self, count: int, character: str = " ") -> None:
         """Pad left and right with a given number of characters.
@@ -796,7 +794,6 @@ class Text(JupyterMixin):
                     raise ValueError(
                         "style must not be set when appending Text instance"
                     )
-
                 text_length = self._length
                 if text.style is not None:
                     self._spans.append(
@@ -868,7 +865,7 @@ class Text(JupyterMixin):
         """Split rich text in to lines, preserving styles.
 
         Args:
-            separator (str, optional): String to split on. Defaults to "\\n".
+            separator (str, optional): String to split on. Defaults to "\\\\n".
             include_separator (bool, optional): Include the separator in the lines. Defaults to False.
             allow_blank (bool, optional): Return a blank line if the text ends with a separator. Defaults to False.
 
@@ -880,17 +877,25 @@ class Text(JupyterMixin):
         text = self.plain
         if separator not in text:
             return Lines([self.copy()])
+
+        if include_separator:
+            lines = self.divide(
+                match.end() for match in re.finditer(re.escape(separator), text)
+            )
+        else:
+
+            def flatten_spans() -> Iterable[int]:
+                for match in re.finditer(re.escape(separator), text):
+                    start, end = match.span()
+                    yield start
+                    yield end
+
+            lines = Lines(
+                line for line in self.divide(flatten_spans()) if line.plain != separator
+            )
+
         if not allow_blank and text.endswith(separator):
-            text = text[: -len(separator)]
-        offsets = [
-            match.start() + 1 for match in re.finditer(re.escape(separator), text)
-        ]
-        lines = self.divide(offsets)
-        if not include_separator:
-            separator_length = len(separator)
-            for line in lines:
-                if line.plain.endswith(separator):
-                    line.right_crop(separator_length)
+            lines.pop()
 
         return lines
 
@@ -903,12 +908,13 @@ class Text(JupyterMixin):
         Returns:
             Lines: New RichText instances between offsets.
         """
-        if not offsets:
+        _offsets = list(offsets)
+        if not _offsets:
             return Lines([self.copy()])
 
         text = self.plain
         text_length = len(text)
-        divide_offsets = [0, *offsets, text_length]
+        divide_offsets = [0, *_offsets, text_length]
         line_ranges = list(zip(divide_offsets, divide_offsets[1:]))
 
         style = self.style
@@ -958,7 +964,19 @@ class Text(JupyterMixin):
 
     def right_crop(self, amount: int = 1) -> None:
         """Remove a number of characters from the end of the text."""
-        self.plain = self.plain[:-amount]
+        max_offset = len(self.plain) - amount
+        _Span = Span
+        self._spans[:] = [
+            (
+                span
+                if span.end < max_offset
+                else _Span(span.start, min(max_offset, span.end), span.style)
+            )
+            for span in self._spans
+            if span.start < max_offset
+        ]
+        self._text = [self.plain[:-amount]]
+        self._length -= amount
 
     def wrap(
         self,
